$SimpleAuthResponse class abstract interface

Implementers

Properties

$$fields List<DataField<SimpleAuthResponse, dynamic>>
no setter
$$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? accessToken, String? refreshToken}) SimpleAuthResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

$accessToken → DataField<SimpleAuthResponse, String>
final
$refreshToken → DataField<SimpleAuthResponse, String>
final
bean → DataBean<SimpleAuthResponse>
final

Static Methods

fromJson(dynamic data, {String? name}) SimpleAuthResponse
fromValues(Map<String, dynamic> data) SimpleAuthResponse

Constants

$$codec → const JsonDataCodec