ApertureSession class
Constructors
- ApertureSession({required Jwt token, required String identity, required String username})
Properties
- debugName → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity → String
-
Returns a unique identifier of the user / account.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → Jwt
-
final
- username → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited