ModuleDescription class

Inheritance
Annotations
  • @Data.new()

Constructors

ModuleDescription({required String id, required String displayName, required int icon, required ModuleType type, required Map<String, dynamic> configuration})
const

Properties

$$fields List<DataField<ModuleDescription, dynamic>>
no setterinherited
$$name String
no setterinherited
configuration Map<String, dynamic>
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
icon int
final
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ModuleType
final

Methods

copyWith({String? id, String? displayName, int? icon, ModuleType? type, Map<String, dynamic>? configuration}) ModuleDescription
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited