SimpleAuthRefreshRequest class

Inheritance
Annotations
  • @Data.new()

Constructors

SimpleAuthRefreshRequest({required String refreshToken})
const

Properties

$$fields List<DataField<SimpleAuthRefreshRequest, dynamic>>
no setterinherited
$$name String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
refreshToken String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? refreshToken}) SimpleAuthRefreshRequest
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited