SimpleAuthRequest class

Inheritance
Annotations
  • @Data.new()

Constructors

SimpleAuthRequest({required String username, required String password})
const

Properties

$$fields List<DataField<SimpleAuthRequest, dynamic>>
no setterinherited
$$name String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
password String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final

Methods

copyWith({String? username, String? password}) SimpleAuthRequest
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited