ResourceRelationFilter class
- Inheritance
-
- Object
- $ResourceRelationFilter
- ResourceRelationFilter
- Annotations
-
- @Data.new()
Constructors
-
ResourceRelationFilter({List<
ResourceRelationFilter> ? or = const [], List<ResourceRelationFilter> ? and = const [], String? fieldId, ResourceFilterType? type, String? value, String? valueFieldId}) -
const
Properties
-
$$fields
→ List<
DataField< ResourceRelationFilter, dynamic> > -
no setterinherited
- $$name → String
-
no setterinherited
-
and
→ List<
ResourceRelationFilter> ? -
final
- fieldId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
or
→ List<
ResourceRelationFilter> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ResourceFilterType?
-
final
- value → String?
-
final
- valueFieldId → String?
-
final
Methods
-
copyWith(
{List< ResourceRelationFilter> ? or, bool nullOr = false, List<ResourceRelationFilter> ? and, bool nullAnd = false, String? fieldId, bool nullFieldId = false, ResourceFilterType? type, bool nullType = false, String? value, bool nullValue = false, String? valueFieldId, bool nullValueFieldId = false}) → ResourceRelationFilter -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited