ResourceRevisionRequest class
- Inheritance
-
- Object
- $ResourceRevisionRequest
- ResourceRevisionRequest
- Annotations
-
- @Data.new()
Constructors
-
ResourceRevisionRequest({required Map<
String, dynamic> fieldData, DateTime? from}) -
const
Properties
-
$$fields
→ List<
DataField< ResourceRevisionRequest, dynamic> > -
no setterinherited
- $$name → String
-
no setterinherited
-
fieldData
→ Map<
String, dynamic> -
final
- from → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Map< String, dynamic> ? fieldData, DateTime? from, bool nullFrom = false}) → ResourceRevisionRequest -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited